@@ -19,20 +19,21 @@ class TemplateBackend:
     django-postageapp)
     """
 
-    def __init__(self, fail_silently=False, **kwargs):
-        api_key = getattr(settings,'POSTAGEAPP_API_KEY',getattr(settings,'EMAIL_POSTAGEAPP_API_KEY',None))
+    def __init__(self, fail_silently=False, api_key=None, **kwargs):
+        api_key = api_key or getattr(settings,'POSTAGEAPP_API_KEY',getattr(settings,'EMAIL_POSTAGEAPP_API_KEY',None))
         if api_key:
             self.conn = PostageApp(api_key)
         else:
             raise ImproperlyConfigured('You need to provide POSTAGEAPP_API_KEY or EMAIL_POSTAGEAPP_API_KEY in your Django settings file') 
 
-    def send(self, template_name, from_email, recipient_list, context, fail_silently=False):
+    def send(self, template_name, from_email, recipient_list, context, fail_silently=False, headers={}):
         try:
             result = self.conn.send_message(
                 recipients=recipient_list,
                 from_email=from_email,
                 template=template_name,
                 variables=context,
+                headers=headers
             )
         except Exception, e:
             if not fail_silently:
